Bayesian Hessian Approximation for Stochastic Optimization
----------------------------------------------------------

We use Bayesian inference to approximate the Hessian of a function given noisy observations of its gradient.
This package can be used in combination with MICE_.

.. _MICE: https://pypi.org/project/mice/
